# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/devices/topicMux.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/devices/topicMux.proto',
  package='ubii.proto_v2.types.devices',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*ubii/proto_v2/types/devices/topicMux.proto\x12\x1bubii.proto_v2.types.devices\"o\n\x08TopicMux\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdata_type\x18\x03 \x01(\t\x12\x16\n\x0etopic_selector\x18\x04 \x01(\t\x12\x1e\n\x16identity_match_pattern\x18\x05 \x01(\t\"G\n\x0cTopicMuxList\x12\x37\n\x08\x65lements\x18\x01 \x03(\x0b\x32%.ubii.proto_v2.types.devices.TopicMuxb\x06proto3'
)




_TOPICMUX = _descriptor.Descriptor(
  name='TopicMux',
  full_name='ubii.proto_v2.types.devices.TopicMux',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.devices.TopicMux.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.devices.TopicMux.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ubii.proto_v2.types.devices.TopicMux.data_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_selector', full_name='ubii.proto_v2.types.devices.TopicMux.topic_selector', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity_match_pattern', full_name='ubii.proto_v2.types.devices.TopicMux.identity_match_pattern', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=186,
)


_TOPICMUXLIST = _descriptor.Descriptor(
  name='TopicMuxList',
  full_name='ubii.proto_v2.types.devices.TopicMuxList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.devices.TopicMuxList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=259,
)

_TOPICMUXLIST.fields_by_name['elements'].message_type = _TOPICMUX
DESCRIPTOR.message_types_by_name['TopicMux'] = _TOPICMUX
DESCRIPTOR.message_types_by_name['TopicMuxList'] = _TOPICMUXLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicMux = _reflection.GeneratedProtocolMessageType('TopicMux', (_message.Message,), {
  'DESCRIPTOR' : _TOPICMUX,
  '__module__' : 'ubii.proto_v2.types.devices.topicMux_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.TopicMux)
  })
_sym_db.RegisterMessage(TopicMux)

TopicMuxList = _reflection.GeneratedProtocolMessageType('TopicMuxList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICMUXLIST,
  '__module__' : 'ubii.proto_v2.types.devices.topicMux_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.TopicMuxList)
  })
_sym_db.RegisterMessage(TopicMuxList)


# @@protoc_insertion_point(module_scope)



#!/usr/bin/python

import sys
import argparse
import os
import platform
import subprocess

from distutils.spawn import find_executable

# Find the Protocol Compiler.
flatc_local = os.path.join(os.path.dirname(__file__), '../external/bin/flatc')
flatc_local_windows = os.path.join(
    os.path.dirname(__file__), '../external/bin/flatc.exe')
if os.path.isfile(flatc_local):
    flatc = flatc_local
elif os.path.isfile(flatc_local_windows):
    flatc = flatc_local_windows
elif 'FLATC' in os.environ and os.path.exists(os.environ['FLATC']):
    flatc = os.environ['FLATC']
else:
    flatc = find_executable("flatc")


def generateInits(pathToOutput):

    dirn = []
    start = True

    while len(dirn) != 0 or start:
        if start:
            p = pathToOutput
        else:
            p = dirn.pop(0)

        for (dirpath, dirnames, filenames) in os.walk(p):
            dirn.extend([p+"/"+x for x in dirnames])
            filename = dirpath+'/__init__.py'
            # print(filename)
            os.makedirs(os.path.dirname(filename), exist_ok=True)
            if start != True:
                with open(filename, "w") as f:
                    pass
            break

        start = False


def getAllSourceFilesFBS(rootDirectory):

    dirn = []
    files = []
    start = True

    while len(dirn) != 0 or start:
        if start:
            p = rootDirectory
        else:
            p = dirn.pop(0)

        start = False
        for (dirpath, dirnames, filenames) in os.walk(p):
            dirn.extend([p+"/"+x for x in dirnames])
            #destdir.extend([po+"/"+x for x in dirnames])
            files.extend(p+"/"+x for x in filenames)
            break

    return files


def compileFBS(sourceFile, outputPath, includePath, targetLanguage, require=True):
    """Invokes the Protocol Compiler to generate a language specific from the given
    .fbs file.  Does nothing if the output already exists and is newer than
    the input."""

    if not require and not os.path.exists(sourceFile):
        return

    #print('path to output: '+outputPath)

    if not os.path.exists(sourceFile):
        sys.stderr.write("Can't find required file: %s\n" % sourceFile)
        sys.exit(-1)

    if flatc is None:
        sys.stderr.write(
            "flatc is not installed nor found in /external/bin.  Please compile it "
            "or install the binary package.\n")
        sys.exit(-1)

    flatc_command = [flatc, "--" + targetLanguage,
                     "-I", includePath, "-o", outputPath]
    # if targetLanguage == "js":
    #    flatc_command.append("--es6-js-export")
    flatc_command.append(sourceFile)
    # print(flatc_command)
    if subprocess.call(flatc_command) != 0:
        sys.exit(-1)


def compileAllFBS(outputPath='./../dist/flatbuffers/py', sourceRoot='./../src/flatbuffers', includePath='./../src/flatbuffers', targetLanguage='python'):
    fileList = getAllSourceFilesFBS(sourceRoot)
    # print(fileList)
    os.makedirs(outputPath, exist_ok=True)

    """ if targetLanguage == 'js':
        ### build js library
        pathToOutputLibrary = 'library=protobuf_library,binary:' + outputPath
        flatc_command = [ flatc, "-I"+includePath, "-I.", "--"+targetLanguage+"_out="+pathToOutputLibrary ]
        for i in fileList:
            flatc_command.append(i)
        print(flatc_command)
        if subprocess.call(flatc_command) != 0:
            sys.exit(-1)

        # prepare output path for individual file compilation
        outputPath = 'import_style=commonjs,binary:' + outputPath """

    for f in fileList:
        compileFBS(f, outputPath, includePath, targetLanguage, False)

    return outputPath


def chosen_option(args):
    file_directory = os.path.dirname(__file__)
    fbs_src_directory = os.path.join(file_directory, '../src/flatbuffers')
    include_directory = fbs_src_directory

    destination_root = '../dist/flatbuffers'
    if args.lang == 'py' or args.lang == 'python':
        p = compileAllFBS(os.path.join(file_directory, destination_root+'/py'),
                          fbs_src_directory, include_directory, 'python')
        generateInits(p)
    elif args.lang == 'j' or args.lang == 'java':
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/java'), fbs_src_directory, include_directory, 'java')
    elif args.lang == 'js' or args.lang == 'javascript':
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/js'), fbs_src_directory, include_directory, 'js')
    elif args.lang == 'cs' or args.lang == 'csharp':
        compileAllFBS(os.path.join(file_directory, destination_root+'/cs'),
                      fbs_src_directory, include_directory, 'csharp')
    elif args.lang == 'cpp' or args.lang == 'cplusplus':
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/cpp'), fbs_src_directory, include_directory, 'cpp')
    elif args.lang == 'all':
        # python
        p = compileAllFBS(os.path.join(file_directory, destination_root+'/py'),
                          fbs_src_directory, include_directory, 'python')
        generateInits(p)
        # java
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/java'), fbs_src_directory, include_directory, 'java')
        # javascript
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/js'), fbs_src_directory, include_directory, 'js')
        # C#
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/cs'), fbs_src_directory, include_directory, 'csharp')
        # C++
        compileAllFBS(os.path.join(file_directory, destination_root +
                                   '/cpp'), fbs_src_directory, include_directory, 'cpp')


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--lang', type=str, default='all',
                        help='Supported options: [cpp] cplusplus, [py] python, [j] java, [js] javascript, [cs] csharp, [all] all')

    args = parser.parse_args()
    sys.stdout.write(str(chosen_option(args)))


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/quaternion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/quaternion.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2ubii/proto_v2/types/dataStructure/quaternion.proto\x12!ubii.proto_v2.types.dataStructure\"8\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\t\n\x01w\x18\x04 \x01(\x01\"Q\n\x0eQuaternionList\x12?\n\x08\x65lements\x18\x01 \x03(\x0b\x32-.ubii.proto_v2.types.dataStructure.Quaternionb\x06proto3'
)




_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='ubii.proto_v2.types.dataStructure.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='ubii.proto_v2.types.dataStructure.Quaternion.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='ubii.proto_v2.types.dataStructure.Quaternion.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='ubii.proto_v2.types.dataStructure.Quaternion.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='ubii.proto_v2.types.dataStructure.Quaternion.w', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=145,
)


_QUATERNIONLIST = _descriptor.Descriptor(
  name='QuaternionList',
  full_name='ubii.proto_v2.types.dataStructure.QuaternionList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.QuaternionList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=228,
)

_QUATERNIONLIST.fields_by_name['elements'].message_type = _QUATERNION
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
DESCRIPTOR.message_types_by_name['QuaternionList'] = _QUATERNIONLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'ubii.proto_v2.types.dataStructure.quaternion_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)

QuaternionList = _reflection.GeneratedProtocolMessageType('QuaternionList', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNIONLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.quaternion_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.QuaternionList)
  })
_sym_db.RegisterMessage(QuaternionList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.clients.client_pb_plus import (
    Client,
    ClientList,
)


__all__ = (
    "Client",
    "ClientList",
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/vector2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/vector2.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/ubii/proto_v2/types/dataStructure/vector2.proto\x12!ubii.proto_v2.types.dataStructure\"\x1f\n\x07Vector2\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"K\n\x0bVector2List\x12<\n\x08\x65lements\x18\x01 \x03(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector2b\x06proto3'
)




_VECTOR2 = _descriptor.Descriptor(
  name='Vector2',
  full_name='ubii.proto_v2.types.dataStructure.Vector2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='ubii.proto_v2.types.dataStructure.Vector2.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='ubii.proto_v2.types.dataStructure.Vector2.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=117,
)


_VECTOR2LIST = _descriptor.Descriptor(
  name='Vector2List',
  full_name='ubii.proto_v2.types.dataStructure.Vector2List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.Vector2List.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=194,
)

_VECTOR2LIST.fields_by_name['elements'].message_type = _VECTOR2
DESCRIPTOR.message_types_by_name['Vector2'] = _VECTOR2
DESCRIPTOR.message_types_by_name['Vector2List'] = _VECTOR2LIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vector2 = _reflection.GeneratedProtocolMessageType('Vector2', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR2,
  '__module__' : 'ubii.proto_v2.types.dataStructure.vector2_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Vector2)
  })
_sym_db.RegisterMessage(Vector2)

Vector2List = _reflection.GeneratedProtocolMessageType('Vector2List', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR2LIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.vector2_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Vector2List)
  })
_sym_db.RegisterMessage(Vector2List)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/buttonEventType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/buttonEventType.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7ubii/proto_v2/types/dataStructure/buttonEventType.proto\x12!ubii.proto_v2.types.dataStructure*#\n\x0f\x42uttonEventType\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x62\x06proto3'
)

_BUTTONEVENTTYPE = _descriptor.EnumDescriptor(
  name='ButtonEventType',
  full_name='ubii.proto_v2.types.dataStructure.ButtonEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=94,
  serialized_end=129,
)
_sym_db.RegisterEnumDescriptor(_BUTTONEVENTTYPE)

ButtonEventType = enum_type_wrapper.EnumTypeWrapper(_BUTTONEVENTTYPE)
UP = 0
DOWN = 1


DESCRIPTOR.enum_types_by_name['ButtonEventType'] = _BUTTONEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/devices/component.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/devices/component.proto',
  package='ubii.proto_v2.types.devices',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+ubii/proto_v2/types/devices/component.proto\x12\x1bubii.proto_v2.types.devices\"\xeb\x01\n\tComponent\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\x12>\n\x07io_type\x18\x03 \x01(\x0e\x32-.ubii.proto_v2.types.devices.Component.IOType\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\"\'\n\x06IOType\x12\r\n\tPUBLISHER\x10\x00\x12\x0e\n\nSUBSCRIBER\x10\x01\"I\n\rComponentList\x12\x38\n\x08\x65lements\x18\x01 \x03(\x0b\x32&.ubii.proto_v2.types.devices.Componentb\x06proto3'
)



_COMPONENT_IOTYPE = _descriptor.EnumDescriptor(
  name='IOType',
  full_name='ubii.proto_v2.types.devices.Component.IOType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLISHER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUBSCRIBER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=273,
  serialized_end=312,
)
_sym_db.RegisterEnumDescriptor(_COMPONENT_IOTYPE)


_COMPONENT = _descriptor.Descriptor(
  name='Component',
  full_name='ubii.proto_v2.types.devices.Component',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.devices.Component.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_format', full_name='ubii.proto_v2.types.devices.Component.message_format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_type', full_name='ubii.proto_v2.types.devices.Component.io_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='ubii.proto_v2.types.devices.Component.device_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.devices.Component.tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.devices.Component.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.devices.Component.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.devices.Component.name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPONENT_IOTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=312,
)


_COMPONENTLIST = _descriptor.Descriptor(
  name='ComponentList',
  full_name='ubii.proto_v2.types.devices.ComponentList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.devices.ComponentList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=387,
)

_COMPONENT.fields_by_name['io_type'].enum_type = _COMPONENT_IOTYPE
_COMPONENT_IOTYPE.containing_type = _COMPONENT
_COMPONENTLIST.fields_by_name['elements'].message_type = _COMPONENT
DESCRIPTOR.message_types_by_name['Component'] = _COMPONENT
DESCRIPTOR.message_types_by_name['ComponentList'] = _COMPONENTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT,
  '__module__' : 'ubii.proto_v2.types.devices.component_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.Component)
  })
_sym_db.RegisterMessage(Component)

ComponentList = _reflection.GeneratedProtocolMessageType('ComponentList', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTLIST,
  '__module__' : 'ubii.proto_v2.types.devices.component_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.ComponentList)
  })
_sym_db.RegisterMessage(ComponentList)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/color.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/color.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/dataStructure/color.proto\x12!ubii.proto_v2.types.dataStructure\"3\n\x05\x43olor\x12\t\n\x01r\x18\x01 \x01(\x01\x12\t\n\x01g\x18\x02 \x01(\x01\x12\t\n\x01\x62\x18\x03 \x01(\x01\x12\t\n\x01\x61\x18\x04 \x01(\x01\x62\x06proto3'
)




_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='ubii.proto_v2.types.dataStructure.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='ubii.proto_v2.types.dataStructure.Color.r', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='ubii.proto_v2.types.dataStructure.Color.g', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='ubii.proto_v2.types.dataStructure.Color.b', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='ubii.proto_v2.types.dataStructure.Color.a', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=135,
)

DESCRIPTOR.message_types_by_name['Color'] = _COLOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), {
  'DESCRIPTOR' : _COLOR,
  '__module__' : 'ubii.proto_v2.types.dataStructure.color_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Color)
  })
_sym_db.RegisterMessage(Color)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
)

from ubii.proto_v1.types.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
    TopicDataRecordList,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicData",
    }
)


class TopicData(Message):
    topic_data_record = Field(
        TopicDataRecord,
        number=2,
        oneof='type',
    )
    topic_data_record_list = Field(
        TopicDataRecordList,
        number=3,
        oneof='type',
    )
    error = Field(
        Error,
        number=4,
        oneof='type',
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.clients.client_pb_plus import (
    Client,
    ClientList,
)

from ubii.proto_v1.types.devices.device_pb_plus import (
    Device,
    DeviceList,
)

from ubii.proto_v1.types.devices.topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from ubii.proto_v1.types.devices.topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)

from ubii.proto_v1.types.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingRequest,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ProcessingModule,
    ProcessingModuleList,
)

from ubii.proto_v1.types.services.request.topicSubscription_pb_plus import (
    TopicSubscription,
)

from ubii.proto_v1.types.sessions.session_pb_plus import (
    Session,
    SessionList,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "ServiceRequest",
    }
)


class ServiceRequest(Message):
    topic = Field(
        STRING,
        number=1,
    )
    client = Field(
        Client,
        number=2,
        oneof='type',
    )
    device = Field(
        Device,
        number=3,
        oneof='type',
    )
    topic_subscription = Field(
        TopicSubscription,
        number=4,
        oneof='type',
    )
    session = Field(
        Session,
        number=5,
        oneof='type',
    )
    session_list = Field(
        SessionList,
        number=6,
        oneof='type',
    )
    processing_module = Field(
        ProcessingModule,
        number=7,
        oneof='type',
    )
    processing_module_list = Field(
        ProcessingModuleList,
        number=8,
        oneof='type',
    )
    topic_mux = Field(
        TopicMux,
        number=9,
        oneof='type',
    )
    topic_mux_list = Field(
        TopicMuxList,
        number=10,
        oneof='type',
    )
    topic_demux = Field(
        TopicDemux,
        number=11,
        oneof='type',
    )
    topic_demux_list = Field(
        TopicDemuxList,
        number=12,
        oneof='type',
    )
    client_list = Field(
        ClientList,
        number=13,
        oneof='type',
    )
    device_list = Field(
        DeviceList,
        number=14,
        oneof='type',
    )
    lockstep_processing_request = Field(
        LockstepProcessingRequest,
        number=15,
        oneof='type',
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Enum,
    FLOAT,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TouchEvent",
        "TouchEventList",
    }
)


class TouchEvent(Message):
    class TouchEventType(Enum):
        TOUCH_START = 0
        TOUCH_MOVE = 1
        TOUCH_END = 2


    type = Field(
        TouchEventType,
        number=1,
    )
    position = Field(
        Vector2,
        number=2,
    )
    id = Field(
        STRING,
        number=3,
    )
    force = Field(
        FLOAT,
        number=4,
    )



class TouchEventList(Message):
    elements = RepeatedField(
        TouchEvent,
        number=1,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/sessions/ioMappings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.devices import topicMux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2
from ubii.proto_v2.types.devices import topicDemux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/sessions/ioMappings.proto',
  package='ubii.proto_v2.types.sessions',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/sessions/ioMappings.proto\x12\x1cubii.proto_v2.types.sessions\x1a*ubii/proto_v2/types/devices/topicMux.proto\x1a,ubii/proto_v2/types/devices/topicDemux.proto\"\x84\x01\n\x11TopicInputMapping\x12\x12\n\ninput_name\x18\x01 \x01(\t\x12\x0f\n\x05topic\x18\x02 \x01(\tH\x00\x12:\n\ttopic_mux\x18\x03 \x01(\x0b\x32%.ubii.proto_v2.types.devices.TopicMuxH\x00\x42\x0e\n\x0ctopic_source\"Z\n\x15TopicInputMappingList\x12\x41\n\x08\x65lements\x18\x01 \x03(\x0b\x32/.ubii.proto_v2.types.sessions.TopicInputMapping\"\x8f\x01\n\x12TopicOutputMapping\x12\x13\n\x0boutput_name\x18\x01 \x01(\t\x12\x0f\n\x05topic\x18\x02 \x01(\tH\x00\x12>\n\x0btopic_demux\x18\x03 \x01(\x0b\x32\'.ubii.proto_v2.types.devices.TopicDemuxH\x00\x42\x13\n\x11topic_destination\"\\\n\x16TopicOutputMappingList\x12\x42\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x30.ubii.proto_v2.types.sessions.TopicOutputMapping\"\xdd\x01\n\tIOMapping\x12\x1c\n\x14processing_module_id\x18\x01 \x01(\t\x12G\n\x0einput_mappings\x18\x02 \x03(\x0b\x32/.ubii.proto_v2.types.sessions.TopicInputMapping\x12I\n\x0foutput_mappings\x18\x03 \x03(\x0b\x32\x30.ubii.proto_v2.types.sessions.TopicOutputMapping\x12\x1e\n\x16processing_module_name\x18\x04 \x01(\t\"J\n\rIOMappingList\x12\x39\n\x08\x65lements\x18\x01 \x03(\x0b\x32\'.ubii.proto_v2.types.sessions.IOMappingb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2.DESCRIPTOR,])




_TOPICINPUTMAPPING = _descriptor.Descriptor(
  name='TopicInputMapping',
  full_name='ubii.proto_v2.types.sessions.TopicInputMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_name', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.input_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_mux', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.topic_mux', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='topic_source', full_name='ubii.proto_v2.types.sessions.TopicInputMapping.topic_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=170,
  serialized_end=302,
)


_TOPICINPUTMAPPINGLIST = _descriptor.Descriptor(
  name='TopicInputMappingList',
  full_name='ubii.proto_v2.types.sessions.TopicInputMappingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.TopicInputMappingList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=394,
)


_TOPICOUTPUTMAPPING = _descriptor.Descriptor(
  name='TopicOutputMapping',
  full_name='ubii.proto_v2.types.sessions.TopicOutputMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_name', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.output_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_demux', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.topic_demux', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='topic_destination', full_name='ubii.proto_v2.types.sessions.TopicOutputMapping.topic_destination',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=397,
  serialized_end=540,
)


_TOPICOUTPUTMAPPINGLIST = _descriptor.Descriptor(
  name='TopicOutputMappingList',
  full_name='ubii.proto_v2.types.sessions.TopicOutputMappingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.TopicOutputMappingList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=542,
  serialized_end=634,
)


_IOMAPPING = _descriptor.Descriptor(
  name='IOMapping',
  full_name='ubii.proto_v2.types.sessions.IOMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_module_id', full_name='ubii.proto_v2.types.sessions.IOMapping.processing_module_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_mappings', full_name='ubii.proto_v2.types.sessions.IOMapping.input_mappings', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_mappings', full_name='ubii.proto_v2.types.sessions.IOMapping.output_mappings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_module_name', full_name='ubii.proto_v2.types.sessions.IOMapping.processing_module_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=858,
)


_IOMAPPINGLIST = _descriptor.Descriptor(
  name='IOMappingList',
  full_name='ubii.proto_v2.types.sessions.IOMappingList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.IOMappingList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=934,
)

_TOPICINPUTMAPPING.fields_by_name['topic_mux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2._TOPICMUX
_TOPICINPUTMAPPING.oneofs_by_name['topic_source'].fields.append(
  _TOPICINPUTMAPPING.fields_by_name['topic'])
_TOPICINPUTMAPPING.fields_by_name['topic'].containing_oneof = _TOPICINPUTMAPPING.oneofs_by_name['topic_source']
_TOPICINPUTMAPPING.oneofs_by_name['topic_source'].fields.append(
  _TOPICINPUTMAPPING.fields_by_name['topic_mux'])
_TOPICINPUTMAPPING.fields_by_name['topic_mux'].containing_oneof = _TOPICINPUTMAPPING.oneofs_by_name['topic_source']
_TOPICINPUTMAPPINGLIST.fields_by_name['elements'].message_type = _TOPICINPUTMAPPING
_TOPICOUTPUTMAPPING.fields_by_name['topic_demux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2._TOPICDEMUX
_TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination'].fields.append(
  _TOPICOUTPUTMAPPING.fields_by_name['topic'])
_TOPICOUTPUTMAPPING.fields_by_name['topic'].containing_oneof = _TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination']
_TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination'].fields.append(
  _TOPICOUTPUTMAPPING.fields_by_name['topic_demux'])
_TOPICOUTPUTMAPPING.fields_by_name['topic_demux'].containing_oneof = _TOPICOUTPUTMAPPING.oneofs_by_name['topic_destination']
_TOPICOUTPUTMAPPINGLIST.fields_by_name['elements'].message_type = _TOPICOUTPUTMAPPING
_IOMAPPING.fields_by_name['input_mappings'].message_type = _TOPICINPUTMAPPING
_IOMAPPING.fields_by_name['output_mappings'].message_type = _TOPICOUTPUTMAPPING
_IOMAPPINGLIST.fields_by_name['elements'].message_type = _IOMAPPING
DESCRIPTOR.message_types_by_name['TopicInputMapping'] = _TOPICINPUTMAPPING
DESCRIPTOR.message_types_by_name['TopicInputMappingList'] = _TOPICINPUTMAPPINGLIST
DESCRIPTOR.message_types_by_name['TopicOutputMapping'] = _TOPICOUTPUTMAPPING
DESCRIPTOR.message_types_by_name['TopicOutputMappingList'] = _TOPICOUTPUTMAPPINGLIST
DESCRIPTOR.message_types_by_name['IOMapping'] = _IOMAPPING
DESCRIPTOR.message_types_by_name['IOMappingList'] = _IOMAPPINGLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicInputMapping = _reflection.GeneratedProtocolMessageType('TopicInputMapping', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINPUTMAPPING,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicInputMapping)
  })
_sym_db.RegisterMessage(TopicInputMapping)

TopicInputMappingList = _reflection.GeneratedProtocolMessageType('TopicInputMappingList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICINPUTMAPPINGLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicInputMappingList)
  })
_sym_db.RegisterMessage(TopicInputMappingList)

TopicOutputMapping = _reflection.GeneratedProtocolMessageType('TopicOutputMapping', (_message.Message,), {
  'DESCRIPTOR' : _TOPICOUTPUTMAPPING,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicOutputMapping)
  })
_sym_db.RegisterMessage(TopicOutputMapping)

TopicOutputMappingList = _reflection.GeneratedProtocolMessageType('TopicOutputMappingList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICOUTPUTMAPPINGLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.TopicOutputMappingList)
  })
_sym_db.RegisterMessage(TopicOutputMappingList)

IOMapping = _reflection.GeneratedProtocolMessageType('IOMapping', (_message.Message,), {
  'DESCRIPTOR' : _IOMAPPING,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.IOMapping)
  })
_sym_db.RegisterMessage(IOMapping)

IOMappingList = _reflection.GeneratedProtocolMessageType('IOMappingList', (_message.Message,), {
  'DESCRIPTOR' : _IOMAPPINGLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.ioMappings_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.IOMappingList)
  })
_sym_db.RegisterMessage(IOMappingList)


# @@protoc_insertion_point(module_scope)



import sys
import setuptools
try:
    from importlib import metadata
except ImportError: # for Python<3.8
    import importlib_metadata as metadata

# disable file finder of setuptools_scm, maybe change MANIFEST.in sometime
try:
    import setuptools_scm.integration
    setuptools_scm.integration.find_files = lambda _: []
except ImportError:
    pass

build_proto_name = 'build_py_proto'
build_cmds = [c for c in metadata.entry_points()['distutils.commands']
              if c.name == build_proto_name]

if not build_cmds:
    print(f"No distutils command with name {build_proto_name} found."
          f" Did you install the `ubii-msg-compiler` package?")
    sys.exit(1)
else:
    assert len(build_cmds) == 1
    build_py = build_cmds[0].load()

setuptools.setup(
    cmdclass={
        'build_py': build_py,
        build_proto_name: build_py,
    }
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/services/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/services/service.proto',
  package='ubii.proto_v2.types.services',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*ubii/proto_v2/types/services/service.proto\x12\x1cubii.proto_v2.types.services\"|\n\x07Service\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x1e\n\x16request_message_format\x18\x02 \x01(\t\x12\x1f\n\x17response_message_format\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"F\n\x0bServiceList\x12\x37\n\x08\x65lements\x18\x01 \x03(\x0b\x32%.ubii.proto_v2.types.services.Serviceb\x06proto3'
)




_SERVICE = _descriptor.Descriptor(
  name='Service',
  full_name='ubii.proto_v2.types.services.Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.services.Service.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_message_format', full_name='ubii.proto_v2.types.services.Service.request_message_format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_message_format', full_name='ubii.proto_v2.types.services.Service.response_message_format', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.services.Service.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.services.Service.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=200,
)


_SERVICELIST = _descriptor.Descriptor(
  name='ServiceList',
  full_name='ubii.proto_v2.types.services.ServiceList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.services.ServiceList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=272,
)

_SERVICELIST.fields_by_name['elements'].message_type = _SERVICE
DESCRIPTOR.message_types_by_name['Service'] = _SERVICE
DESCRIPTOR.message_types_by_name['ServiceList'] = _SERVICELIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Service = _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), {
  'DESCRIPTOR' : _SERVICE,
  '__module__' : 'ubii.proto_v2.types.services.service_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.services.Service)
  })
_sym_db.RegisterMessage(Service)

ServiceList = _reflection.GeneratedProtocolMessageType('ServiceList', (_message.Message,), {
  'DESCRIPTOR' : _SERVICELIST,
  '__module__' : 'ubii.proto_v2.types.services.service_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.services.ServiceList)
  })
_sym_db.RegisterMessage(ServiceList)


# @@protoc_insertion_point(module_scope)



import dataclasses
from dataclasses import dataclass


@dataclass(frozen=True)
class _DefaultTopics:
    """
    This is a nested dataclass that contains all defined constants for Ubi Interact Default
    Topics. The node should check if the constants are up-to-date by comparing the constants with the
    constants_json field of the Server message the master node sends for a SERVER_CONFIG service request.

    The dataclass is frozen, so you are not allowed to change the constants.
    It also implements the iterable interface, thus calling `iter` on the class (e.g. implicitly
    when using it in a loop) will work correctly.
    It also implements an `items` method, which is just a wrapper to call dataclasses.asdict(cls).items()
    """

    @dataclass(frozen=True)
    class Services:
        SERVER_CONFIG: str = '/services/server_configuration'
        CLIENT_REGISTRATION: str = '/services/client/registration'
        CLIENT_DEREGISTRATION: str = '/services/client/deregistration'
        CLIENT_GET_LIST: str = '/services/client/get_list'
        DEVICE_REGISTRATION: str = '/services/device/registration'
        DEVICE_DEREGISTRATION: str = '/services/device/deregistration'
        DEVICE_GET: str = '/services/device/get'
        DEVICE_GET_LIST: str = '/services/device/get_list'
        LATENCY_CLIENTS_LIST: str = '/services/latency_clients_list'
        PM_DATABASE_SAVE: str = '/services/processing_module/database/save'
        PM_DATABASE_DELETE: str = '/services/processing_module/database/delete'
        PM_DATABASE_GET: str = '/services/processing_module/database/get'
        PM_DATABASE_GET_LIST: str = '/services/processing_module/database/get_list'
        PM_DATABASE_ONLINE_GET_LIST: str = '/services/processing_module/database/online/get_list'
        PM_DATABASE_LOCAL_GET_LIST: str = '/services/processing_module/database/local/get_list'
        PM_RUNTIME_ADD: str = '/services/processing_module/runtime/add'
        PM_RUNTIME_REMOVE: str = '/services/processing_module/runtime/remove'
        PM_RUNTIME_GET: str = '/services/processing_module/runtime/get'
        PM_RUNTIME_GET_LIST: str = '/services/processing_module/runtime/get_list'
        SESSION_DATABASE_SAVE: str = '/services/session/database/save'
        SESSION_DATABASE_DELETE: str = '/services/session/database/delete'
        SESSION_DATABASE_GET: str = '/services/session/database/get'
        SESSION_DATABASE_GET_LIST: str = '/services/session/database/get_list'
        SESSION_DATABASE_ONLINE_GET_LIST: str = '/services/session/database/online/get_list'
        SESSION_DATABASE_LOCAL_GET_LIST: str = '/services/session/database/local/get_list'
        SESSION_RUNTIME_ADD: str = '/services/session/runtime/add'
        SESSION_RUNTIME_REMOVE: str = '/services/session/runtime/remove'
        SESSION_RUNTIME_GET: str = '/services/session/runtime/get'
        SESSION_RUNTIME_GET_LIST: str = '/services/session/runtime/get_list'
        SESSION_RUNTIME_START: str = '/services/session/runtime/start'
        SESSION_RUNTIME_STOP: str = '/services/session/runtime/stop'
        SESSION_RUNTIME_UPDATE: str = '/services/session/runtime/update'
        TOPIC_DEMUX_DATABASE_SAVE: str = '/services/device/topic_demux/database/save'
        TOPIC_DEMUX_DATABASE_DELETE: str = '/services/device/topic_demux/database/delete'
        TOPIC_DEMUX_DATABASE_GET: str = '/services/device/topic_demux/database/get'
        TOPIC_DEMUX_DATABASE_GET_LIST: str = '/services/device/topic_demux/database/get_list'
        TOPIC_DEMUX_RUNTIME_GET: str = '/services/device/topic_demux/runtime/get'
        TOPIC_DEMUX_RUNTIME_GET_LIST: str = '/services/device/topic_demux/runtime/get_list'
        TOPIC_MUX_DATABASE_SAVE: str = '/services/device/topic_mux/database/save'
        TOPIC_MUX_DATABASE_DELETE: str = '/services/device/topic_mux/database/delete'
        TOPIC_MUX_DATABASE_GET: str = '/services/device/topic_mux/database/get'
        TOPIC_MUX_DATABASE_GET_LIST: str = '/services/device/topic_mux/database/get_list'
        TOPIC_MUX_RUNTIME_GET: str = '/services/device/topic_mux/runtime/get'
        TOPIC_MUX_RUNTIME_GET_LIST: str = '/services/device/topic_mux/runtime/get_list'
        SERVICE_LIST: str = '/services/service_list'
        TOPIC_LIST: str = '/services/topic_list'
        TOPIC_SUBSCRIPTION: str = '/services/topic_subscription'

        def __iter__(self):
            yield from dataclasses.asdict(self)

        def items(self):
            yield from dataclasses.asdict(self).items()

    @dataclass(frozen=True)
    class InfoTopics:
        REGEX_ALL_INFOS: str = '/info/*'
        REGEX_PM_INFOS: str = '/info/processing_module/*'
        NEW_PM: str = '/info/processing_module/new'
        DELETE_PM: str = '/info/processing_module/delete'
        CHANGE_PM: str = '/info/processing_module/change'
        PROCESSED_PM: str = '/info/processing_module/processed'
        REGEX_SESSION_INFOS: str = '/info/session/*'
        NEW_SESSION: str = '/info/session/new'
        DELETE_SESSION: str = '/info/session/delete'
        CHANGE_SESSION: str = '/info/session/change'
        START_SESSION: str = '/info/session/start'
        STOP_SESSION: str = '/info/session/stop'
        RUNNING_SESSION: str = '/info/session/running'
        START_PM: str = '/info/processing_module/start'

        def __iter__(self):
            yield from dataclasses.asdict(self)

        def items(self):
            yield from dataclasses.asdict(self).items()

        @property
        def regexes(self):
            return [self.REGEX_SESSION_INFOS, self.REGEX_PM_INFOS, self.REGEX_ALL_INFOS]

    SERVICES: Services = Services()
    INFO_TOPICS: InfoTopics = InfoTopics()

    def __post_init__(self):
        if isinstance(self.SERVICES, dict):
            object.__setattr__(self, 'SERVICES', self.Services(**self.SERVICES))

        if isinstance(self.INFO_TOPICS, dict):
            object.__setattr__(self, 'INFO_TOPICS', self.Services(**self.SERVICES))

    def __iter__(self):
        yield from dataclasses.asdict(self)

    def items(self):
        yield from dataclasses.asdict(self).items()


DEFAULT_TOPICS = _DefaultTopics()


@dataclass(frozen=True)
class _MsgTypes:
    """
    This is a dataclass that contains all defined constants for Ubi Interact Message Types.
    These can be used as paths for imports relative to the `proto` module, see `ProtoTranslators`.
    The node should check if the constants are up-to-date by comparing the constants with the
    constants_json field of the Server message the master node sends for a SERVER_CONFIG service request.

    The dataclass is frozen, so you are not allowed to change the constants.
    It also implements the iterable interface, thus calling `iter` on the class (e.g. implicitly
    when using it in a loop) will work correctly.
    It also implements an `items` method, which is just a wrapper to call dataclasses.asdict(cls).items()
    """
    proto_package = 'ubii'

    ERROR: str = proto_package + '.general.Error'
    SUCCESS: str = proto_package + '.general.Success'
    SERVER: str = proto_package + '.servers.Server'
    CLIENT: str = proto_package + '.clients.Client'
    CLIENT_LIST: str = proto_package + '.clients.ClientList'
    DEVICE: str = proto_package + '.devices.Device'
    DEVICE_LIST: str = proto_package + '.devices.DeviceList'
    COMPONENT: str = proto_package + '.devices.Component'
    COMPONENT_LIST: str = proto_package + '.devices.ComponentList'
    TOPIC_MUX: str = proto_package + '.devices.TopicMux'
    TOPIC_MUX_LIST: str = proto_package + '.devices.TopicMuxList'
    TOPIC_DEMUX: str = proto_package + '.devices.TopicDemux'
    TOPIC_DEMUX_LIST: str = proto_package + '.devices.TopicDemuxList'
    SERVICE: str = proto_package + '.services.Service'
    SERVICE_LIST: str = proto_package + '.services.ServiceList'
    SERVICE_REQUEST: str = proto_package + '.services.ServiceRequest'
    SERVICE_REPLY: str = proto_package + '.services.ServiceReply'
    SERVICE_REUEST_TOPIC_SUBSCRIPTION: str = proto_package + '.services.request.TopicSubscription'
    SESSION: str = proto_package + '.sessions.Session'
    SESSION_LIST: str = proto_package + '.sessions.SessionList'
    SESSION_IO_MAPPING: str = proto_package + '.sessions.IOMapping'
    PM: str = proto_package + '.processing.ProcessingModule'
    PM_LIST: str = proto_package + '.processing.ProcessingModuleList'
    PM_MODULE_IO: str = proto_package + '.processing.ModuleIO'
    PM_PROCESSING_MODE: str = proto_package + '.processing.ProcessingMode'
    TOPIC_DATA: str = proto_package + '.topicData.TopicData'
    TOPIC_DATA_RECORD: str = proto_package + '.topicData.TopicDataRecord'
    TOPIC_DATA_RECORD_LIST: str = proto_package + '.topicData.TopicDataRecordList'
    TOPIC_DATA_TIMESTAMP: str = proto_package + '.topicData.Timestamp'
    DATASTRUCTURE_BOOL: str = "bool"
    DATASTRUCTURE_INT32: str = "int32"
    DATASTRUCTURE_STRING: str = "string"
    DATASTRUCTURE_FLOAT: str = "float"
    DATASTRUCTURE_DOUBLE: str = "double"
    DATASTRUCTURE_BOOL_LIST: str = proto_package + '.dataStructure.BoolList'
    DATASTRUCTURE_INT32_LIST: str = proto_package + '.dataStructure.Int32List'
    DATASTRUCTURE_STRING_LIST: str = proto_package + '.dataStructure.StringList'
    DATASTRUCTURE_FLOAT_LIST: str = proto_package + '.dataStructure.FloatList'
    DATASTRUCTURE_DOUBLE_LIST: str = proto_package + '.dataStructure.DoubleList'
    DATASTRUCTURE_COLOR: str = proto_package + '.dataStructure.Color'
    DATASTRUCTURE_IMAGE: str = proto_package + '.dataStructure.Image2D'
    DATASTRUCTURE_IMAGE_LIST: str = proto_package + '.dataStructure.Image2DList'
    DATASTRUCTURE_KEY_EVENT: str = proto_package + '.dataStructure.KeyEvent'
    DATASTRUCTURE_MATRIX_3X2: str = proto_package + '.dataStructure.Matrix3x2'
    DATASTRUCTURE_MATRIX_4X4: str = proto_package + '.dataStructure.Matrix4x4'
    DATASTRUCTURE_MOUSE_EVENT: str = proto_package + '.dataStructure.MouseEvent'
    DATASTRUCTURE_OBJECT2D: str = proto_package + '.dataStructure.Object2D'
    DATASTRUCTURE_OBJECT2D_LIST: str = proto_package + '.dataStructure.Object2DList'
    DATASTRUCTURE_OBJECT3D: str = proto_package + '.dataStructure.Object3D'
    DATASTRUCTURE_OBJECT3D_LIST: str = proto_package + '.dataStructure.Object3DList'
    DATASTRUCTURE_POSE2D: str = proto_package + '.dataStructure.Pose2D'
    DATASTRUCTURE_POSE3D: str = proto_package + '.dataStructure.Pose3D'
    DATASTRUCTURE_QUATERNION: str = proto_package + '.dataStructure.Quaternion'
    DATASTRUCTURE_TOUCH_EVENT: str = proto_package + '.dataStructure.TouchEvent'
    DATASTRUCTURE_VECTOR2: str = proto_package + '.dataStructure.Vector2'
    DATASTRUCTURE_VECTOR3: str = proto_package + '.dataStructure.Vector3'
    DATASTRUCTURE_VECTOR4: str = proto_package + '.dataStructure.Vector4'
    DATASTRUCTURE_VECTOR8: str = proto_package + '.dataStructure.Vector8'

    def __iter__(self):
        yield from dataclasses.asdict(self)

    def items(self):
        yield from dataclasses.asdict(self).items()


MSG_TYPES = _MsgTypes()



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Service",
        "ServiceList",
    }
)


class Service(Message):
    topic = Field(
        STRING,
        number=1,
    )
    request_message_format = Field(
        STRING,
        number=2,
    )
    response_message_format = Field(
        STRING,
        number=3,
    )
    tags = RepeatedField(
        STRING,
        number=4,
    )
    description = Field(
        STRING,
        number=5,
    )



class ServiceList(Message):
    elements = RepeatedField(
        Service,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Enum,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Component",
        "ComponentList",
    }
)


class Component(Message):
    class IOType(Enum):
        PUBLISHER = 0
        SUBSCRIBER = 1


    topic = Field(
        STRING,
        number=1,
    )
    message_format = Field(
        STRING,
        number=2,
    )
    io_type = Field(
        IOType,
        number=3,
    )
    device_id = Field(
        STRING,
        number=4,
    )
    tags = RepeatedField(
        STRING,
        number=5,
    )
    description = Field(
        STRING,
        number=6,
    )
    id = Field(
        STRING,
        number=7,
    )
    name = Field(
        STRING,
        number=8,
    )



class ComponentList(Message):
    elements = RepeatedField(
        Component,
        number=1,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/handGestureType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/handGestureType.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7ubii/proto_v2/types/dataStructure/handGestureType.proto\x12!ubii.proto_v2.types.dataStructure*d\n\x0fHandGestureType\x12\x08\n\x04REST\x10\x00\x12\x12\n\x0e\x46INGERS_SPREAD\x10\x01\x12\x0b\n\x07WAVE_IN\x10\x02\x12\x0c\n\x08WAVE_OUT\x10\x03\x12\x08\n\x04\x46IST\x10\x04\x12\x0e\n\nDOUBLE_TAP\x10\x05\x62\x06proto3'
)

_HANDGESTURETYPE = _descriptor.EnumDescriptor(
  name='HandGestureType',
  full_name='ubii.proto_v2.types.dataStructure.HandGestureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINGERS_SPREAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAVE_IN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAVE_OUT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_TAP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=94,
  serialized_end=194,
)
_sym_db.RegisterEnumDescriptor(_HANDGESTURETYPE)

HandGestureType = enum_type_wrapper.EnumTypeWrapper(_HANDGESTURETYPE)
REST = 0
FINGERS_SPREAD = 1
WAVE_IN = 2
WAVE_OUT = 3
FIST = 4
DOUBLE_TAP = 5


DESCRIPTOR.enum_types_by_name['HandGestureType'] = _HANDGESTURETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



import importlib
import logging
from collections import namedtuple
from importlib.metadata import version, PackageNotFoundError

from proto import Message as ProtoPlusMessage

import ubii.proto
from .constants import MSG_TYPES

try:
    __version__ = version("ubii-msg-formats")
except PackageNotFoundError:
    __version__ = None

log = logging.getLogger(__name__)
__imported_types__ = {}

import_name = namedtuple('import_name', ['package', 'type'])


def get_import_name(message_type: str):
    """
    The .proto files declare a package name 'ubii', but this is not reflected in the python package.
    Instead the package is named ubii.proto, to not clash with different packages in the ubii namespace.
    The python files are generated from updated proto files, to produce the correct directory structure.
    The directory structure determines python package names see
    https://developers.google.com/protocol-buffers/docs/reference/python-generated#package

    :param message_type: string describing the data type
    """

    if not message_type.startswith('ubii.'):
        raise ValueError(f"{message_type} does not seem to be a special ubi-interact message type.")

    package, typ = message_type.replace(
        MSG_TYPES.proto_package, ubii.proto.__proto_module__
    ).rsplit('.', maxsplit=1)

    return import_name(package=package, type=typ)


def import_type(message_type: str, reimport=False):
    """
    See the documentation of the ubii-msg-compiler at https://github.com/saggitar/ubii-msg-compiler
    for more information about updating the .proto files to generate a different package structure.

    :param message_type: string describing the data type
    :param reimport: If true force reimport of type
    """

    def _import(name: str) -> ProtoPlusMessage:
        package, type_ = get_import_name(name)
        package = importlib.import_module(package)
        type_ = getattr(package, type_, None)

        if type_ is None:
            raise ValueError(f"{name} could not be imported.")
        return type_

    if message_type not in __imported_types__ or reimport:
        __imported_types__[message_type] = _import(message_type)

    return __imported_types__[message_type]



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.clients.client_pb_plus import (
    Client,
    ClientList,
)

from ubii.proto_v1.types.dataStructure.buttonEventType_pb_plus import (
    ButtonEventType,
)

from ubii.proto_v1.types.dataStructure.color_pb_plus import (
    Color,
)

from ubii.proto_v1.types.dataStructure.handGestureType_pb_plus import (
    HandGestureType,
)

from ubii.proto_v1.types.dataStructure.image_pb_plus import (
    Image2D,
    Image2DList,
)

from ubii.proto_v1.types.dataStructure.keyEvent_pb_plus import (
    KeyEvent,
)

from ubii.proto_v1.types.dataStructure.lists_pb_plus import (
    BoolList,
    DoubleList,
    FloatList,
    Int32List,
    StringList,
)

from ubii.proto_v1.types.dataStructure.matrix3x2_pb_plus import (
    Matrix3x2,
)

from ubii.proto_v1.types.dataStructure.matrix4x4_pb_plus import (
    Matrix4x4,
)

from ubii.proto_v1.types.dataStructure.mouseEvent_pb_plus import (
    MouseEvent,
)

from ubii.proto_v1.types.dataStructure.myoEvent_pb_plus import (
    MyoEvent,
)

from ubii.proto_v1.types.dataStructure.object2d_pb_plus import (
    Object2D,
    Object2DList,
)

from ubii.proto_v1.types.dataStructure.object3d_pb_plus import (
    Object3D,
    Object3DList,
)

from ubii.proto_v1.types.dataStructure.pose2d_pb_plus import (
    Pose2D,
)

from ubii.proto_v1.types.dataStructure.pose3d_pb_plus import (
    Pose3D,
)

from ubii.proto_v1.types.dataStructure.quaternion_pb_plus import (
    Quaternion,
    QuaternionList,
)

from ubii.proto_v1.types.dataStructure.touchEvent_pb_plus import (
    TouchEvent,
    TouchEventList,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
    Vector2List,
)

from ubii.proto_v1.types.dataStructure.vector3_pb_plus import (
    Vector3,
    Vector3List,
)

from ubii.proto_v1.types.dataStructure.vector4_pb_plus import (
    Vector4,
    Vector4List,
)

from ubii.proto_v1.types.dataStructure.vector8_pb_plus import (
    Vector8,
    Vector8List,
)

from ubii.proto_v1.types.devices.component_pb_plus import (
    Component,
    ComponentList,
)

from ubii.proto_v1.types.devices.device_pb_plus import (
    Device,
    DeviceList,
)

from ubii.proto_v1.types.devices.topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from ubii.proto_v1.types.devices.topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)

from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
    ErrorList,
)

from ubii.proto_v1.types.general.success_pb_plus import (
    Success,
    SuccessList,
)

from ubii.proto_v1.types.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingReply,
    LockstepProcessingRequest,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ModuleIO,
    ProcessingMode,
    ProcessingModule,
    ProcessingModuleList,
)

from ubii.proto_v1.types.servers.constants_pb_plus import (
    Constants,
)

from ubii.proto_v1.types.servers.server_pb_plus import (
    Server,
)

from ubii.proto_v1.types.services.request.topicSubscription_pb_plus import (
    TopicSubscription,
)

from ubii.proto_v1.types.services.serviceReply_pb_plus import (
    ServiceReply,
)

from ubii.proto_v1.types.services.serviceRequest_pb_plus import (
    ServiceRequest,
)

from ubii.proto_v1.types.services.service_pb_plus import (
    Service,
    ServiceList,
)

from ubii.proto_v1.types.sessions.ioMappings_pb_plus import (
    IOMapping,
    IOMappingList,
    TopicInputMapping,
    TopicInputMappingList,
    TopicOutputMapping,
    TopicOutputMappingList,
)

from ubii.proto_v1.types.sessions.session_pb_plus import (
    Session,
    SessionList,
    SessionStatus,
)

from ubii.proto_v1.types.topicData.timestamp_pb_plus import (
    Timestamp,
)

from ubii.proto_v1.types.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
    TopicDataRecordList,
)

from ubii.proto_v1.types.topicData.topicData_pb_plus import (
    TopicData,
)


__all__ = (
    "Client",
    "ClientList",
    "ButtonEventType",
    "HandGestureType",
    "Color",
    "Image2D",
    "Image2DList",
    "KeyEvent",
    "StringList",
    "DoubleList",
    "FloatList",
    "BoolList",
    "Int32List",
    "Matrix3x2",
    "Matrix4x4",
    "MouseEvent",
    "MyoEvent",
    "Object2D",
    "Object2DList",
    "Object3D",
    "Object3DList",
    "Pose2D",
    "Pose3D",
    "Quaternion",
    "QuaternionList",
    "TouchEvent",
    "TouchEventList",
    "Vector2",
    "Vector2List",
    "Vector3",
    "Vector3List",
    "Vector4",
    "Vector4List",
    "Vector8",
    "Vector8List",
    "Component",
    "ComponentList",
    "Device",
    "DeviceList",
    "TopicDemux",
    "TopicDemuxList",
    "TopicMux",
    "TopicMuxList",
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
    "LockstepProcessingRequest",
    "LockstepProcessingReply",
    "ProcessingMode",
    "ModuleIO",
    "ProcessingModule",
    "ProcessingModuleList",
    "Constants",
    "Server",
    "Service",
    "ServiceList",
    "ServiceReply",
    "ServiceRequest",
    "TopicSubscription",
    "SessionStatus",
    "TopicInputMapping",
    "TopicInputMappingList",
    "TopicOutputMapping",
    "TopicOutputMappingList",
    "IOMapping",
    "IOMappingList",
    "Session",
    "SessionList",
    "Timestamp",
    "TopicData",
    "TopicDataRecord",
    "TopicDataRecordList",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.clients.client_pb_plus import (
    Client,
    ClientList,
)

from ubii.proto_v1.types.dataStructure.lists_pb_plus import (
    StringList,
)

from ubii.proto_v1.types.devices.device_pb_plus import (
    Device,
    DeviceList,
)

from ubii.proto_v1.types.devices.topicDemux_pb_plus import (
    TopicDemux,
    TopicDemuxList,
)

from ubii.proto_v1.types.devices.topicMux_pb_plus import (
    TopicMux,
    TopicMuxList,
)

from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
)

from ubii.proto_v1.types.general.success_pb_plus import (
    Success,
)

from ubii.proto_v1.types.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingReply,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ProcessingModule,
    ProcessingModuleList,
)

from ubii.proto_v1.types.servers.server_pb_plus import (
    Server,
)

from ubii.proto_v1.types.services.service_pb_plus import (
    Service,
    ServiceList,
)

from ubii.proto_v1.types.sessions.session_pb_plus import (
    Session,
    SessionList,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "ServiceReply",
    }
)


class ServiceReply(Message):
    success = Field(
        Success,
        number=1,
        oneof='type',
    )
    error = Field(
        Error,
        number=2,
        oneof='type',
    )
    client = Field(
        Client,
        number=3,
        oneof='type',
    )
    device = Field(
        Device,
        number=4,
        oneof='type',
    )
    server = Field(
        Server,
        number=5,
        oneof='type',
    )
    session = Field(
        Session,
        number=6,
        oneof='type',
    )
    session_list = Field(
        SessionList,
        number=7,
        oneof='type',
    )
    processing_module = Field(
        ProcessingModule,
        number=8,
        oneof='type',
    )
    processing_module_list = Field(
        ProcessingModuleList,
        number=9,
        oneof='type',
    )
    string_list = Field(
        StringList,
        number=10,
        oneof='type',
    )
    topic_mux = Field(
        TopicMux,
        number=11,
        oneof='type',
    )
    topic_mux_list = Field(
        TopicMuxList,
        number=12,
        oneof='type',
    )
    topic_demux = Field(
        TopicDemux,
        number=13,
        oneof='type',
    )
    topic_demux_list = Field(
        TopicDemuxList,
        number=14,
        oneof='type',
    )
    client_list = Field(
        ClientList,
        number=15,
        oneof='type',
    )
    device_list = Field(
        DeviceList,
        number=16,
        oneof='type',
    )
    service = Field(
        Service,
        number=17,
        oneof='type',
    )
    service_list = Field(
        ServiceList,
        number=18,
        oneof='type',
    )
    lockstep_processing_reply = Field(
        LockstepProcessingReply,
        number=19,
        oneof='type',
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/pose2d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.dataStructure import vector2_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/pose2d.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.ubii/proto_v2/types/dataStructure/pose2d.proto\x12!ubii.proto_v2.types.dataStructure\x1a/ubii/proto_v2/types/dataStructure/vector2.proto\"\xa7\x01\n\x06Pose2D\x12<\n\x08position\x18\x01 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector2\x12?\n\tdirection\x18\x02 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector2H\x00\x12\x0f\n\x05\x61ngle\x18\x03 \x01(\x02H\x00\x42\r\n\x0borientationb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2.DESCRIPTOR,])




_POSE2D = _descriptor.Descriptor(
  name='Pose2D',
  full_name='ubii.proto_v2.types.dataStructure.Pose2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='ubii.proto_v2.types.dataStructure.Pose2D.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='ubii.proto_v2.types.dataStructure.Pose2D.direction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angle', full_name='ubii.proto_v2.types.dataStructure.Pose2D.angle', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='orientation', full_name='ubii.proto_v2.types.dataStructure.Pose2D.orientation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=135,
  serialized_end=302,
)

_POSE2D.fields_by_name['position'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2._VECTOR2
_POSE2D.fields_by_name['direction'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2._VECTOR2
_POSE2D.oneofs_by_name['orientation'].fields.append(
  _POSE2D.fields_by_name['direction'])
_POSE2D.fields_by_name['direction'].containing_oneof = _POSE2D.oneofs_by_name['orientation']
_POSE2D.oneofs_by_name['orientation'].fields.append(
  _POSE2D.fields_by_name['angle'])
_POSE2D.fields_by_name['angle'].containing_oneof = _POSE2D.oneofs_by_name['orientation']
DESCRIPTOR.message_types_by_name['Pose2D'] = _POSE2D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pose2D = _reflection.GeneratedProtocolMessageType('Pose2D', (_message.Message,), {
  'DESCRIPTOR' : _POSE2D,
  '__module__' : 'ubii.proto_v2.types.dataStructure.pose2d_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Pose2D)
  })
_sym_db.RegisterMessage(Pose2D)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/touchEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.dataStructure import buttonEventType_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_buttonEventType__pb2
from ubii.proto_v2.types.dataStructure import vector2_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/touchEvent.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2ubii/proto_v2/types/dataStructure/touchEvent.proto\x12!ubii.proto_v2.types.dataStructure\x1a\x37ubii/proto_v2/types/dataStructure/buttonEventType.proto\x1a/ubii/proto_v2/types/dataStructure/vector2.proto\"\xf3\x01\n\nTouchEvent\x12J\n\x04type\x18\x01 \x01(\x0e\x32<.ubii.proto_v2.types.dataStructure.TouchEvent.TouchEventType\x12<\n\x08position\x18\x02 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector2\x12\n\n\x02id\x18\x03 \x01(\t\x12\r\n\x05\x66orce\x18\x04 \x01(\x02\"@\n\x0eTouchEventType\x12\x0f\n\x0bTOUCH_START\x10\x00\x12\x0e\n\nTOUCH_MOVE\x10\x01\x12\r\n\tTOUCH_END\x10\x02\"Q\n\x0eTouchEventList\x12?\n\x08\x65lements\x18\x01 \x03(\x0b\x32-.ubii.proto_v2.types.dataStructure.TouchEventb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_buttonEventType__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2.DESCRIPTOR,])



_TOUCHEVENT_TOUCHEVENTTYPE = _descriptor.EnumDescriptor(
  name='TouchEventType',
  full_name='ubii.proto_v2.types.dataStructure.TouchEvent.TouchEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TOUCH_START', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOUCH_MOVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOUCH_END', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=375,
  serialized_end=439,
)
_sym_db.RegisterEnumDescriptor(_TOUCHEVENT_TOUCHEVENTTYPE)


_TOUCHEVENT = _descriptor.Descriptor(
  name='TouchEvent',
  full_name='ubii.proto_v2.types.dataStructure.TouchEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ubii.proto_v2.types.dataStructure.TouchEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='ubii.proto_v2.types.dataStructure.TouchEvent.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.dataStructure.TouchEvent.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='ubii.proto_v2.types.dataStructure.TouchEvent.force', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOUCHEVENT_TOUCHEVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=439,
)


_TOUCHEVENTLIST = _descriptor.Descriptor(
  name='TouchEventList',
  full_name='ubii.proto_v2.types.dataStructure.TouchEventList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.TouchEventList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=522,
)

_TOUCHEVENT.fields_by_name['type'].enum_type = _TOUCHEVENT_TOUCHEVENTTYPE
_TOUCHEVENT.fields_by_name['position'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2._VECTOR2
_TOUCHEVENT_TOUCHEVENTTYPE.containing_type = _TOUCHEVENT
_TOUCHEVENTLIST.fields_by_name['elements'].message_type = _TOUCHEVENT
DESCRIPTOR.message_types_by_name['TouchEvent'] = _TOUCHEVENT
DESCRIPTOR.message_types_by_name['TouchEventList'] = _TOUCHEVENTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TouchEvent = _reflection.GeneratedProtocolMessageType('TouchEvent', (_message.Message,), {
  'DESCRIPTOR' : _TOUCHEVENT,
  '__module__' : 'ubii.proto_v2.types.dataStructure.touchEvent_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.TouchEvent)
  })
_sym_db.RegisterMessage(TouchEvent)

TouchEventList = _reflection.GeneratedProtocolMessageType('TouchEventList', (_message.Message,), {
  'DESCRIPTOR' : _TOUCHEVENTLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.touchEvent_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.TouchEventList)
  })
_sym_db.RegisterMessage(TouchEventList)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/services/serviceReply.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.general import success_pb2 as ubii_dot_proto__v2_dot_types_dot_general_dot_success__pb2
from ubii.proto_v2.types.general import error_pb2 as ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2
from ubii.proto_v2.types.dataStructure import lists_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2
from ubii.proto_v2.types.clients import client_pb2 as ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2
from ubii.proto_v2.types.devices import device_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2
from ubii.proto_v2.types.devices import topicMux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2
from ubii.proto_v2.types.devices import topicDemux_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2
from ubii.proto_v2.types.servers import server_pb2 as ubii_dot_proto__v2_dot_types_dot_servers_dot_server__pb2
from ubii.proto_v2.types.sessions import session_pb2 as ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2
from ubii.proto_v2.types.services import service_pb2 as ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2
from ubii.proto_v2.types.processing import processingModule_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2
from ubii.proto_v2.types.processing import lockstepProcessing_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_lockstepProcessing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/services/serviceReply.proto',
  package='ubii.proto_v2.types.services',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/ubii/proto_v2/types/services/serviceReply.proto\x12\x1cubii.proto_v2.types.services\x1a)ubii/proto_v2/types/general/success.proto\x1a\'ubii/proto_v2/types/general/error.proto\x1a-ubii/proto_v2/types/dataStructure/lists.proto\x1a(ubii/proto_v2/types/clients/client.proto\x1a(ubii/proto_v2/types/devices/device.proto\x1a*ubii/proto_v2/types/devices/topicMux.proto\x1a,ubii/proto_v2/types/devices/topicDemux.proto\x1a(ubii/proto_v2/types/servers/server.proto\x1a*ubii/proto_v2/types/sessions/session.proto\x1a*ubii/proto_v2/types/services/service.proto\x1a\x35ubii/proto_v2/types/processing/processingModule.proto\x1a\x37ubii/proto_v2/types/processing/lockstepProcessing.proto\"\xf8\t\n\x0cServiceReply\x12\x37\n\x07success\x18\x01 \x01(\x0b\x32$.ubii.proto_v2.types.general.SuccessH\x00\x12\x33\n\x05\x65rror\x18\x02 \x01(\x0b\x32\".ubii.proto_v2.types.general.ErrorH\x00\x12\x35\n\x06\x63lient\x18\x03 \x01(\x0b\x32#.ubii.proto_v2.types.clients.ClientH\x00\x12\x35\n\x06\x64\x65vice\x18\x04 \x01(\x0b\x32#.ubii.proto_v2.types.devices.DeviceH\x00\x12\x35\n\x06server\x18\x05 \x01(\x0b\x32#.ubii.proto_v2.types.servers.ServerH\x00\x12\x38\n\x07session\x18\x06 \x01(\x0b\x32%.ubii.proto_v2.types.sessions.SessionH\x00\x12\x41\n\x0csession_list\x18\x07 \x01(\x0b\x32).ubii.proto_v2.types.sessions.SessionListH\x00\x12M\n\x11processing_module\x18\x08 \x01(\x0b\x32\x30.ubii.proto_v2.types.processing.ProcessingModuleH\x00\x12V\n\x16processing_module_list\x18\t \x01(\x0b\x32\x34.ubii.proto_v2.types.processing.ProcessingModuleListH\x00\x12\x44\n\x0bstring_list\x18\n \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.StringListH\x00\x12:\n\ttopic_mux\x18\x0b \x01(\x0b\x32%.ubii.proto_v2.types.devices.TopicMuxH\x00\x12\x43\n\x0etopic_mux_list\x18\x0c \x01(\x0b\x32).ubii.proto_v2.types.devices.TopicMuxListH\x00\x12>\n\x0btopic_demux\x18\r \x01(\x0b\x32\'.ubii.proto_v2.types.devices.TopicDemuxH\x00\x12G\n\x10topic_demux_list\x18\x0e \x01(\x0b\x32+.ubii.proto_v2.types.devices.TopicDemuxListH\x00\x12>\n\x0b\x63lient_list\x18\x0f \x01(\x0b\x32\'.ubii.proto_v2.types.clients.ClientListH\x00\x12>\n\x0b\x64\x65vice_list\x18\x10 \x01(\x0b\x32\'.ubii.proto_v2.types.devices.DeviceListH\x00\x12\x38\n\x07service\x18\x11 \x01(\x0b\x32%.ubii.proto_v2.types.services.ServiceH\x00\x12\x41\n\x0cservice_list\x18\x12 \x01(\x0b\x32).ubii.proto_v2.types.services.ServiceListH\x00\x12\\\n\x19lockstep_processing_reply\x18\x13 \x01(\x0b\x32\x37.ubii.proto_v2.types.processing.LockstepProcessingReplyH\x00\x42\x06\n\x04typeb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_general_dot_success__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_servers_dot_server__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_lockstepProcessing__pb2.DESCRIPTOR,])




_SERVICEREPLY = _descriptor.Descriptor(
  name='ServiceReply',
  full_name='ubii.proto_v2.types.services.ServiceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='ubii.proto_v2.types.services.ServiceReply.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ubii.proto_v2.types.services.ServiceReply.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client', full_name='ubii.proto_v2.types.services.ServiceReply.client', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='ubii.proto_v2.types.services.ServiceReply.device', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server', full_name='ubii.proto_v2.types.services.ServiceReply.server', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='ubii.proto_v2.types.services.ServiceReply.session', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_list', full_name='ubii.proto_v2.types.services.ServiceReply.session_list', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_module', full_name='ubii.proto_v2.types.services.ServiceReply.processing_module', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_module_list', full_name='ubii.proto_v2.types.services.ServiceReply.processing_module_list', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='ubii.proto_v2.types.services.ServiceReply.string_list', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_mux', full_name='ubii.proto_v2.types.services.ServiceReply.topic_mux', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_mux_list', full_name='ubii.proto_v2.types.services.ServiceReply.topic_mux_list', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_demux', full_name='ubii.proto_v2.types.services.ServiceReply.topic_demux', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_demux_list', full_name='ubii.proto_v2.types.services.ServiceReply.topic_demux_list', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_list', full_name='ubii.proto_v2.types.services.ServiceReply.client_list', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_list', full_name='ubii.proto_v2.types.services.ServiceReply.device_list', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='ubii.proto_v2.types.services.ServiceReply.service', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_list', full_name='ubii.proto_v2.types.services.ServiceReply.service_list', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_processing_reply', full_name='ubii.proto_v2.types.services.ServiceReply.lockstep_processing_reply', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ubii.proto_v2.types.services.ServiceReply.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=629,
  serialized_end=1901,
)

_SERVICEREPLY.fields_by_name['success'].message_type = ubii_dot_proto__v2_dot_types_dot_general_dot_success__pb2._SUCCESS
_SERVICEREPLY.fields_by_name['error'].message_type = ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2._ERROR
_SERVICEREPLY.fields_by_name['client'].message_type = ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2._CLIENT
_SERVICEREPLY.fields_by_name['device'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2._DEVICE
_SERVICEREPLY.fields_by_name['server'].message_type = ubii_dot_proto__v2_dot_types_dot_servers_dot_server__pb2._SERVER
_SERVICEREPLY.fields_by_name['session'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2._SESSION
_SERVICEREPLY.fields_by_name['session_list'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2._SESSIONLIST
_SERVICEREPLY.fields_by_name['processing_module'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULE
_SERVICEREPLY.fields_by_name['processing_module_list'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULELIST
_SERVICEREPLY.fields_by_name['string_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._STRINGLIST
_SERVICEREPLY.fields_by_name['topic_mux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2._TOPICMUX
_SERVICEREPLY.fields_by_name['topic_mux_list'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicMux__pb2._TOPICMUXLIST
_SERVICEREPLY.fields_by_name['topic_demux'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2._TOPICDEMUX
_SERVICEREPLY.fields_by_name['topic_demux_list'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_topicDemux__pb2._TOPICDEMUXLIST
_SERVICEREPLY.fields_by_name['client_list'].message_type = ubii_dot_proto__v2_dot_types_dot_clients_dot_client__pb2._CLIENTLIST
_SERVICEREPLY.fields_by_name['device_list'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2._DEVICELIST
_SERVICEREPLY.fields_by_name['service'].message_type = ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2._SERVICE
_SERVICEREPLY.fields_by_name['service_list'].message_type = ubii_dot_proto__v2_dot_types_dot_services_dot_service__pb2._SERVICELIST
_SERVICEREPLY.fields_by_name['lockstep_processing_reply'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_lockstepProcessing__pb2._LOCKSTEPPROCESSINGREPLY
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['success'])
_SERVICEREPLY.fields_by_name['success'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['error'])
_SERVICEREPLY.fields_by_name['error'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['client'])
_SERVICEREPLY.fields_by_name['client'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['device'])
_SERVICEREPLY.fields_by_name['device'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['server'])
_SERVICEREPLY.fields_by_name['server'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['session'])
_SERVICEREPLY.fields_by_name['session'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['session_list'])
_SERVICEREPLY.fields_by_name['session_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['processing_module'])
_SERVICEREPLY.fields_by_name['processing_module'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['processing_module_list'])
_SERVICEREPLY.fields_by_name['processing_module_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['string_list'])
_SERVICEREPLY.fields_by_name['string_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_mux'])
_SERVICEREPLY.fields_by_name['topic_mux'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_mux_list'])
_SERVICEREPLY.fields_by_name['topic_mux_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_demux'])
_SERVICEREPLY.fields_by_name['topic_demux'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['topic_demux_list'])
_SERVICEREPLY.fields_by_name['topic_demux_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['client_list'])
_SERVICEREPLY.fields_by_name['client_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['device_list'])
_SERVICEREPLY.fields_by_name['device_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['service'])
_SERVICEREPLY.fields_by_name['service'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['service_list'])
_SERVICEREPLY.fields_by_name['service_list'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
_SERVICEREPLY.oneofs_by_name['type'].fields.append(
  _SERVICEREPLY.fields_by_name['lockstep_processing_reply'])
_SERVICEREPLY.fields_by_name['lockstep_processing_reply'].containing_oneof = _SERVICEREPLY.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['ServiceReply'] = _SERVICEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceReply = _reflection.GeneratedProtocolMessageType('ServiceReply', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEREPLY,
  '__module__' : 'ubii.proto_v2.types.services.serviceReply_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.services.ServiceReply)
  })
_sym_db.RegisterMessage(ServiceReply)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto_v1.types.dataStructure.vector3_pb_plus import (
    Vector3,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Pose3D",
    }
)


class Pose3D(Message):
    position = Field(
        Vector3,
        number=1,
    )
    quaternion = Field(
        Quaternion,
        number=2,
        oneof='orientation',
    )
    euler = Field(
        Vector3,
        number=3,
        oneof='orientation',
    )


